package main

import (
	"encoding/json"
	"errors"
	"strconv"

	"github.com/sendgrid/rest"
	"github.com/sendgrid/sendgrid-go"
)

type sendgridList struct {
	ID   string `json:"id"`
	Name string `json:"name"`
}

type sendgridListResult struct {
	Result   []sendgridList `json:"result"`
	Metadata struct {
		Next string `json:"next"`
	} `json:"_metadata"`
}

func resolveSengridListID(list string) (string, error) {
	request := sendgrid.GetRequest(
		envSendgridKey,
		"/v3/marketing/lists?page_size=1000",
		"https://api.sendgrid.com",
	)

	for {
		response, err := sendgrid.API(request)
		if err != nil {
			return "", err
		}

		if response.StatusCode/100 != 2 {
			return "", errors.New(strconv.Itoa(response.StatusCode) + ": " + response.Body)
		}

		var result sendgridListResult

		err = json.Unmarshal(([]byte)(response.Body), &result)
		if err != nil {
			return "", err
		}

		for _, l := range result.Result {
			if l.Name == list {
				return l.ID, nil
			}
		}

		request.BaseURL = result.Metadata.Next

		if result.Metadata.Next == "" || len(result.Result) == 0 {
			break
		}
	}

	bs, err := json.Marshal(map[string]interface{}{
		"name": list,
	})
	if err != nil {
		return "", err
	}

	request = sendgrid.GetRequest(envSendgridKey, "/v3/marketing/lists", "https://api.sendgrid.com")
	request.Method = rest.Post
	request.Body = bs

	response, err := sendgrid.API(request)
	if err != nil {
		return "", err
	}

	var result sendgridList

	err = json.Unmarshal(([]byte)(response.Body), &result)
	if err != nil {
		return "", err
	}

	if response.StatusCode/100 != 2 {
		return "", errors.New(strconv.Itoa(response.StatusCode) + ": " + response.Body)
	}

	return result.ID, nil
}
