// Package document provides document embed resolvers
package document

import (
	"context"
	"time"

	document "gitlab.mashroom.com/mashroom/backend/document/api"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/embed"
)

// Resolver returns document for first value
type Resolver struct {
	Document document.DocumentServiceClient
}

// Resolve implementation
func (r *Resolver) Resolve(ctx context.Context, values ...string) (interface{}, error) {
	if len(values) == 0 {
		return nil, nil
	}

	resp, err := r.Document.Get(ctx, &document.GetRequest{Id: values[0]})
	if err != nil {
		return nil, err
	}

	doc := resp.GetDocument()

	data := embed.BindMap(doc)

	expirationDaysLeft := 0

	if doc.GetExpiration() != nil && doc.GetExpiration().IsValid() {
		now := time.Now().Truncate(24 * time.Hour)

		expiration := doc.GetExpiration().AsTime().Truncate(24 * time.Hour)

		if expiration.After(now) {
			days := time.Duration(expiration.Sub(now).Hours() / 24)

			expirationDaysLeft = int(days)
		}
	}

	embed.SetMap(data, expirationDaysLeft, "expiration_days_left")

	return data, nil
}
