// Package invitation provides invitation embed resolvers
package invitation

import (
	"context"
	"fmt"

	account "gitlab.mashroom.com/mashroom/backend/account/api"
	invitation "gitlab.mashroom.com/mashroom/backend/invitation/api"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/embed"
)

// Resolver returns invitation for first value
type Resolver struct {
	Invitation invitation.InvitationServiceClient
	Account    account.AccountServiceClient
	SiteURL    string
}

// Resolve implementation
func (r *Resolver) Resolve(ctx context.Context, values ...string) (interface{}, error) {
	if len(values) == 0 {
		return nil, nil
	}

	resp, err := r.Invitation.GetInvitation(ctx, &invitation.GetInvitationRequest{
		Id: values[0],
	})
	if err != nil {
		return nil, err
	}

	info := resp.GetInfo()

	var role string

	switch info.GetType() {
	case invitation.InvitationType_LANDLORD_INVITATION:
		role = "landlord"
	case invitation.InvitationType_MANAGER_INVITATION:
		role = "manager"
	case invitation.InvitationType_TENANT_INVITATION:
		role = "tenant"
	}

	var username string

	if info.GetInviteeLastName() != "" || info.GetInviteeFirstName() != "" {
		username = embed.JoinNonempty(" ", info.GetInviteeFirstName(), info.GetInviteeLastName())
	} else if info.GetInviteeId() != "" {
		acc, _ := r.Account.Get(ctx, &account.GetRequest{Id: info.GetInviteeId()})
		det := acc.GetAccount().GetDetailsValue()
		username = embed.JoinNonempty(det.GetFirstNameValue(), det.GetLastNameValue())
	}

	link := fmt.Sprintf("%s/dashboard/%s/overview", r.SiteURL, resp.GetInfo().GetPropertyId())

	data := embed.BindMap(resp.GetInfo())

	embed.SetMap(data, role, "role")
	embed.SetMap(data, username, "username")
	embed.SetMap(data, username, "username")
	embed.SetMap(data, link, "link")
	embed.SetMap(data, link, "declinelink")
	embed.SetMap(data, info.GetInviteeEmail(), "email")

	return data, nil
}
