// Package maintenance provides maintenance embed resolvers
package maintenance

import (
	"context"
	"fmt"
	"time"

	"gitlab.mashroom.com/mashroom/backend/notification/internal/embed"

	maintenance "gitlab.mashroom.com/mashroom/backend/maintenance/api"
)

// Resolver returns maintenance for first value
type Resolver struct {
	Maintenance maintenance.MaintenanceServiceClient
	SiteURL     string
}

// Resolve implementation
func (r *Resolver) Resolve(ctx context.Context, values ...string) (interface{}, error) {
	if len(values) == 0 {
		return nil, nil
	}

	resp, err := r.Maintenance.Get(ctx, &maintenance.GetRequest{
		Id:   values[0],
		User: embed.Recipient(ctx),
	})
	if err != nil {
		return nil, err
	}

	link := fmt.Sprintf(
		"https://%s/property/%s/tenancy/maintenance",
		r.SiteURL,
		resp.GetMaintenance().GetProperty(),
	)
	createdAt := resp.GetMaintenance().GetCreatedAt().AsTime().Format(time.RFC1123)
	updatedAt := resp.GetMaintenance().GetUpdatedAt().AsTime().Format(time.RFC1123)

	data := embed.BindMap(resp.GetMaintenance())

	embed.SetMap(data, link, "link")
	embed.SetMap(data, createdAt, "created_at")
	embed.SetMap(data, updatedAt, "updated_at")

	return data, nil
}
