// Package mortgage provides mortgage embed resolvers
package mortgage

import (
	"context"
	"fmt"

	account "gitlab.mashroom.com/mashroom/backend/account/api"
	mortgage "gitlab.mashroom.com/mashroom/backend/mortgage/api"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/embed"
)

// Lead returns mortgage lead for first value
type Lead struct {
	Mortgage mortgage.MortgageServiceClient
	Account  account.AccountServiceClient
	SiteURL  string
}

// Resolve implementation
func (r *Lead) Resolve(ctx context.Context, values ...string) (interface{}, error) {
	if len(values) == 0 {
		return nil, nil
	}

	resp, err := r.Mortgage.LeadGet(ctx, &mortgage.LeadGetRequest{
		Id: values[0],
	})
	if err != nil {
		return nil, err
	}

	adminResp, err := r.Account.Get(ctx, &account.GetRequest{
		Id:    resp.GetLead().GetAdminId(),
		Admin: true,
	})
	if err != nil {
		return nil, err
	}

	adminDetails := adminResp.GetAccount().GetDetailsValue()

	var admin string

	switch {
	case adminDetails.GetFirstNameValue() != "" && adminDetails.GetLastNameValue() != "":
		admin = fmt.Sprintf("%s %s", adminDetails.GetFirstNameValue(), adminDetails.GetLastNameValue())
	case adminDetails.GetFirstNameValue() != "":
		admin = adminDetails.GetFirstNameValue()
	case adminDetails.GetLastNameValue() != "":
		admin = adminDetails.GetLastNameValue()
	case adminResp.GetAccount().GetContactValue().GetEmailPrimaryValue() != "":
		admin = adminResp.GetAccount().GetContactValue().GetEmailPrimaryValue()
	default:
		admin = adminResp.GetAccount().GetIdValue()
	}

	scheduleDate := resp.GetLead().GetScheduleDate().AsTime().Format("2006-01-02 15:04:05")
	link := fmt.Sprintf("%s/admin/lead/%s/details", r.SiteURL, resp.GetLead().GetId())

	data := embed.BindMap(resp.GetLead())

	embed.SetMap(data, scheduleDate, "schedule_date")
	embed.SetMap(data, admin, "admin")
	embed.SetMap(data, link, "link")

	return data, nil
}
