// Package property provides property embed resolvers
package property

import (
	"context"
	"fmt"

	"gitlab.mashroom.com/mashroom/backend/notification/internal/embed"
	property "gitlab.mashroom.com/mashroom/backend/property/api"
)

// Resolver returns property for first value
type Resolver struct {
	Property        property.PropertyServiceClient
	AccountResolver embed.Resolver
	SiteURL         string
}

// Resolve implementation
func (r *Resolver) Resolve(ctx context.Context, values ...string) (interface{}, error) {
	if len(values) == 0 {
		return nil, nil
	}

	resp, err := r.Property.Get(ctx, &property.GetRequest{
		Id:   values[0],
		User: embed.Recipient(ctx),
	})

	if err != nil {
		return nil, err
	}

	loc := resp.GetProperty().GetLocation()

	name := embed.JoinNonempty(
		" ",
		loc.GetBuilding().GetValue(),
		loc.GetFlat().GetValue(),
		loc.GetStreet().GetValue(),
		loc.GetCity().GetValue(),
	)
	link := fmt.Sprintf("%s/property/%s", r.SiteURL, resp.GetProperty().GetId().GetValue())
	manager, err := r.AccountResolver.Resolve(ctx, resp.GetProperty().GetPeople().GetManager().GetValue())

	data := embed.BindMap(resp.GetProperty())

	embed.SetMap(data, name, "name")
	embed.SetMap(data, link, "link")
	embed.SetMap(data, manager, "people", "manager")

	return data, err
}
