// Package tenancy provides tenancy embed resolvers
package tenancy

import (
	"context"

	"gitlab.mashroom.com/mashroom/backend/notification/internal/embed"
	property "gitlab.mashroom.com/mashroom/backend/property/api"
)

// Resolver returns tenancy for first value
type Resolver struct {
	Property property.PropertyServiceClient
}

// Resolve implementation
func (r *Resolver) Resolve(ctx context.Context, values ...string) (interface{}, error) {
	if len(values) == 0 {
		return nil, nil
	}

	resp, err := r.Property.GetTenancy(ctx, &property.GetTenancyRequest{
		By: &property.GetTenancyRequest_Id{
			Id: values[0],
		},
	})
	if err != nil {
		return nil, err
	}

	if len(resp.GetTenancy()) == 0 {
		return nil, nil
	}

	tenancy := resp.GetTenancy()[0]

	movedout := tenancy.GetMovedout().AsTime().Format("02 January 2006")
	terminationDate := tenancy.GetTerminationDate().AsTime().Format("02 January 2006")

	data := embed.BindMap(tenancy)

	embed.SetMap(data, movedout, "movedout")
	embed.SetMap(data, terminationDate, "termination_date")

	return data, nil
}
