// Package time provides time embed resolvers
package time

import (
	"context"
	"strconv"
	"time"
)

// Unix parses first value as UNIX seconds-resolution time and formats with provided format
type Unix struct {
	Format string
}

// Resolve implementation
func (r *Unix) Resolve(ctx context.Context, values ...string) (interface{}, error) {
	if len(values) == 0 {
		return nil, nil
	}

	v, err := strconv.ParseInt(values[0], 10, 64)
	if err != nil {
		return nil, err
	}

	return time.Unix(v, 0).Format(r.Format), nil
}
