// Package user provides user account embed resolvers
package user

import (
	"context"

	account "gitlab.mashroom.com/mashroom/backend/account/api"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/embed"
)

// Resolver returns user account for first value
type Resolver struct {
	Account account.AccountServiceClient
}

// Resolve implementation
func (r *Resolver) Resolve(ctx context.Context, values ...string) (interface{}, error) {
	contacts := embed.Contacts(ctx)

	if len(values) == 0 {
		if contacts != nil {
			data := make(map[string]interface{})

			embed.SetMap(data, contacts.GetFullname(), "name")
			embed.SetMap(data, contacts.GetEmail(), "email")
			embed.SetMap(data, contacts.GetPhone(), "phone")

			return data, nil
		}

		return nil, nil
	}

	resp, err := r.Account.Get(ctx, &account.GetRequest{
		Id: values[0],
	})
	if err != nil {
		if contacts != nil {
			data := make(map[string]interface{})

			embed.SetMap(data, contacts.GetFullname(), "name")
			embed.SetMap(data, contacts.GetEmail(), "email")
			embed.SetMap(data, contacts.GetPhone(), "phone")

			return data, nil
		}

		return nil, err
	}

	det := resp.GetAccount().GetDetailsValue()
	con := resp.GetAccount().GetContactValue()

	name := embed.JoinNonempty(" ", det.GetFirstNameValue(), det.GetLastNameValue())
	email := con.GetEmailPrimaryValue()
	phone := con.GetPhonePrimaryValue()

	if contacts.GetFullname() != "" {
		name = contacts.GetFullname()
	}

	if contacts.GetEmail() != "" {
		email = contacts.GetEmail()
	}

	if contacts.GetPhone() != "" {
		phone = contacts.GetPhone()
	}

	data := embed.BindMap(resp.GetAccount())

	embed.SetMap(data, det.GetFirstNameValue(), "firstname")
	embed.SetMap(data, name, "name")
	embed.SetMap(data, email, "email")
	embed.SetMap(data, phone, "phone")

	return data, nil
}
