// Package viewing provides viewing embed resolvers
package viewing

import (
	"context"
	"fmt"
	"time"

	messaging "gitlab.mashroom.com/mashroom/backend/messaging/api"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/embed"
	property "gitlab.mashroom.com/mashroom/backend/property/api"
)

// Resolver returns viewing for first value
type Resolver struct {
	Property property.PropertyServiceClient
}

// Resolve implementation
func (r *Resolver) Resolve(ctx context.Context, values ...string) (interface{}, error) {
	if len(values) == 0 {
		return nil, nil
	}

	props := embed.Embeds(ctx)[messaging.EmbedType_EMBED_TYPE_PROPERTY]

	if len(props) == 0 {
		return nil, nil
	}

	resp, err := r.Property.GetView(ctx, &property.GetViewRequest{
		Id:       values[0],
		Property: props[0],
		User:     embed.Recipient(ctx),
	})
	if err != nil {
		return nil, err
	}

	t := resp.GetRequest().GetTime()

	m := time.Month(t.GetMonth().GetValue())

	start := t.GetTimeStartsec().GetValue()
	hours := start / 3600
	remainder := start % 3600
	minutes := remainder / 60
	seconds := remainder % 60
	month := m.String()

	if m < time.January || m > time.December {
		month = ""
	}

	data := embed.BindMap(resp.GetRequest())

	embed.SetMap(data, fmt.Sprintf("%02d", hours), "time", "start_hour")
	embed.SetMap(data, fmt.Sprintf("%02d", minutes), "time", "start_minute")
	embed.SetMap(data, fmt.Sprintf("%02d", seconds), "time", "start_seconds")
	embed.SetMap(data, t.GetDay().GetValue(), "time", "day")
	embed.SetMap(data, month, "time", "month")

	return data, nil
}
