// Package assets for notification handlers
package assets

import (
	_ "embed" // embeds
	"strings"
	"text/template"
)

var (
	//go:embed email_template.html
	sourceTemplateEmail string

	//go:embed sms_template.txt
	sourceTemplateSMS string
)

var (
	templateEmail = template.Must(template.New("").Parse(sourceTemplateEmail))
	templateSMS   = template.Must(template.New("").Parse(sourceTemplateSMS))
)

// RenderEmailTemplate renders email body using local template
func RenderEmailTemplate(site, subject, content string) (body string, err error) {
	sb := &strings.Builder{}

	values := map[string]interface{}{
		"subject":   subject,
		"content":   content,
		"loginLink": site,
	}

	err = templateEmail.Execute(sb, values)
	if err != nil {
		return "", err
	}

	res := sb.String()

	if len(res) == 0 {
		res = content
	}

	return res, nil
}

// RenderSMSTemplate renderssms body using local template
func RenderSMSTemplate(site, content string) (body string, err error) {
	sb := &strings.Builder{}

	values := map[string]interface{}{
		"content":   content,
		"loginLink": site,
	}

	err = templateSMS.Execute(sb, values)
	if err != nil {
		return "", err
	}

	res := sb.String()

	if len(res) == 0 {
		res = content
	}

	return res, nil
}
