package platform

import (
	"context"
	"encoding/json"
	"time"

	messaging "gitlab.mashroom.com/mashroom/backend/messaging/api"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/task"
)

type handlerImpl struct {
	config Config
}

func (handler *handlerImpl) Run(ctx context.Context, instance *task.Task) error {
	var t task.Platform

	err := json.Unmarshal(instance.Data, &t)
	if err != nil {
		return err
	}

	if t.Notification != nil {
		nbs, _ := json.Marshal(t.Notification)
		t.Embeds = append(t.Embeds, &messaging.Embed{
			EmbedType:  int32(messaging.EmbedType_EMBED_TYPE_NOTIFICATION),
			EmbedValue: string(nbs),
		})
	}

	title := "New notification"

	if t.Title != "" {
		title = t.Title
	}

	t.Embeds = append(t.Embeds, &messaging.Embed{
		EmbedType:  int32(messaging.EmbedType_EMBED_TYPE_TITLE),
		EmbedValue: title,
	})

	_, err = handler.config.Messaging.ServiceSend(ctx, &messaging.SendRequest{
		Scope:   int32(messaging.ChannelScope_NOTIFICATION_SCOPE),
		Channel: t.UserID,
		Text:    t.Body,
		Embeds:  t.Embeds,
		Event:   t.Event,
	})

	return err
}

func (handler *handlerImpl) RetryPeriod() time.Duration {
	return time.Minute
}
