package smtp

import (
	"bytes"
	"context"
	"encoding/json"
	"time"

	"github.com/domodwyer/mailyak"
	document "gitlab.mashroom.com/mashroom/backend/document/api"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/handlers/assets"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/task"
)

type handlerImpl struct {
	config Config
}

func (handler *handlerImpl) Run(ctx context.Context, instance *task.Task) error {
	var t task.Email

	err := json.Unmarshal(instance.Data, &t)
	if err != nil {
		return err
	}

	mail := mailyak.New(handler.config.SMTPServer, handler.config.SMTPAuth)

	var tos []string

	for _, to := range t.To {
		tos = append(tos, to.Address)
	}

	mail.To(tos...)

	mail.From(handler.config.FromAddress)
	mail.FromName(handler.config.FromName)
	mail.Subject(t.Subject)

	if t.ReplyTo != nil {
		mail.ReplyTo(t.ReplyTo.Address)
	}

	body := t.Body

	if !t.Raw {
		body, err = assets.RenderEmailTemplate(handler.config.Site, t.Subject, body)
		if err != nil {
			return err
		}
	}

	if t.HTML {
		mail.HTML().Set(body)
	} else {
		mail.Plain().Set(body)
	}

	for _, f := range t.Attachments {
		raw := &bytes.Buffer{}

		var info *document.File

		info, err = document.DownloadFile(ctx, handler.config.DocumentService, f, document.ImageSize_ORIGINAL, raw)
		if err != nil {
			return err
		}

		mail.AttachInlineWithMimeType(info.GetName(), raw, info.GetMime())
	}

	return mail.Send()
}

func (handler *handlerImpl) RetryPeriod() time.Duration {
	return time.Minute
}
