package twilio

import (
	"context"
	"encoding/json"
	"fmt"
	"time"

	"gitlab.mashroom.com/mashroom/backend/notification/internal/handlers/assets"

	"gitlab.mashroom.com/mashroom/backend/common/api/grpcerr"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/task"
)

type handlerImpl struct {
	config Config
}

func (handler *handlerImpl) Run(ctx context.Context, instance *task.Task) error {
	var t task.SMS

	err := json.Unmarshal(instance.Data, &t)
	if err != nil {
		return err
	}

	body, err := assets.RenderSMSTemplate(handler.config.Site, t.Body)
	if err != nil {
		return err
	}

	_, excp, err := handler.config.Client.SendSMSWithCopilot(
		handler.config.ServiceSID,
		t.Phone,
		body,
		handler.config.StatusCallback,
		handler.config.ApplicationSID,
	)

	if excp != nil {
		return grpcerr.New(grpcerr.ProviderError, fmt.Sprint(excp))
	}

	return err
}

func (handler *handlerImpl) RetryPeriod() time.Duration {
	return time.Minute
}
