package model

import (
	"database/sql/driver"
	"encoding/json"
	"time"

	messaging "gitlab.mashroom.com/mashroom/backend/messaging/api"
	notification "gitlab.mashroom.com/mashroom/backend/notification/api"
)

// Embeds wrapper
type Embeds []*notification.EventEmbed

// Value returns serialized representation
func (v Embeds) Value() (driver.Value, error) {
	if v == nil {
		return json.Marshal([]*messaging.Embed{})
	}

	return json.Marshal(v)
}

// Scan parses serialized representation
func (v *Embeds) Scan(value interface{}) error {
	if value == nil {
		return nil
	}

	bs, ok := value.([]byte)
	if !ok {
		return nil
	}

	return json.Unmarshal(bs, v)
}

// Log for notifications
type Log struct {
	EventEmbeds  Embeds                    `db:"embeds"`
	Created      time.Time                 `db:"created"`
	Updated      time.Time                 `db:"updated"`
	ID           uint64                    `db:"id"`
	Recipient    string                    `db:"recipient"`
	Email        string                    `db:"email"`
	Phone        string                    `db:"phone"`
	Error        string                    `db:"error"`
	Actor        notification.Role         `db:"actor"`
	Entity       notification.Entity       `db:"entity"`
	Role         notification.Role         `db:"role"`
	Action       notification.Action       `db:"action"`
	Duration     time.Duration             `db:"duration"`
	EventChannel notification.EventChannel `db:"channel"`
	Processed    bool                      `db:"processed"`
}
