package model

import (
	"database/sql/driver"
	"encoding/json"
	"time"

	notification "gitlab.mashroom.com/mashroom/backend/notification/api"
)

// NotificationData wrapper
type NotificationData map[string]string

// Value returns serialized representation
func (v NotificationData) Value() (driver.Value, error) {
	if v == nil {
		return json.Marshal(map[string]string{})
	}

	return json.Marshal(v)
}

// Scan parses serialized representation
func (v *NotificationData) Scan(value interface{}) error {
	if value == nil {
		return nil
	}

	bs, ok := value.([]byte)
	if !ok {
		return nil
	}

	return json.Unmarshal(bs, v)
}

// Contacts stores default notification contacts
type Contacts struct {
	Email    string `json:"email,omitempty"`
	Phone    string `json:"phone,omitempty"`
	Fullname string `json:"fullname,omitempty"`
}

// Value returns serialized representation
func (v Contacts) Value() (driver.Value, error) {
	return json.Marshal(v)
}

// Scan parses serialized representation
func (v *Contacts) Scan(value interface{}) error {
	if value == nil {
		return nil
	}

	bs, ok := value.([]byte)
	if !ok {
		return nil
	}

	return json.Unmarshal(bs, v)
}

// Notification model
type Notification struct {
	Created      time.Time                 `db:"created"`
	Updated      time.Time                 `db:"updated"`
	Contacts     Contacts                  `db:"contacts"`
	Template     string                    `db:"template"`
	ID           uint64                    `db:"id"`
	Duration     time.Duration             `db:"duration"`
	Data         NotificationData          `db:"data"`
	Actor        notification.Role         `db:"actor"`
	Entity       notification.Entity       `db:"entity"`
	Role         notification.Role         `db:"role"`
	Action       notification.Action       `db:"action"`
	Channel      notification.EventChannel `db:"channel"`
	TemplateHTML bool                      `db:"template_html"`
	Disabled     bool                      `db:"disabled"`
	Customized   bool                      `db:"customized"`
}
