package postgres

import (
	"context"

	"github.com/jmoiron/sqlx"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/model"
)

type repositoryLog struct {
	save        *sqlx.NamedStmt
	updateError *sqlx.NamedStmt
}

func prepareLog(db *sqlx.DB) (stmt repositoryLog, err error) {
	stmt.save, err = prepareNamed(db, queryLogSave)
	if err != nil {
		return
	}

	stmt.updateError, err = prepareNamed(db, queryLogUpdateError)
	if err != nil {
		return
	}

	return
}

const queryLogSave = `
insert into notification_logs(
  recipient,
  email,
  phone,
  actor,
  entity,
  role,
  action,
  duration,
  channel,
  embeds,
  error
) values (
  nullif(:recipient, ''),
  nullif(:email, ''),
  nullif(:phone, ''),
  :actor,
  :entity,
  :role,
  :action,
  :duration,
  :channel,
  :embeds,
  nullif(:error, '')
) returning
  id,
  coalesce(recipient, '') as recipient,
  coalesce(email, '') as email,
  coalesce(phone, '') as phone,
  actor,
  entity,
  role,
  action,
  duration,
  channel,
  embeds,
  coalesce(error, '') as error,
  created
`

func (repo *repositoryLog) LogSave(ctx context.Context, m *model.Log) error {
	err := repo.save.GetContext(ctx, m, m)

	return err
}

const queryLogUpdateError = `
update notification_logs set
  error = nullif(:error, ''),
  processed = true,
  updated = now()
where
  id = :id
`

func (repo *repositoryLog) LogUpdateError(ctx context.Context, id uint64, errstr string) error {
	_, err := repo.updateError.ExecContext(ctx, &model.Log{
		ID:    id,
		Error: errstr,
	})

	return err
}
