create table notifications(
  id             bigserial primary key,
  recipient      text,
  email          text,
  phone          text,
  event_type     int4,
  event_channel  int4 not null,
  event_embeds   jsonb not null,
  error          text,
  user_id        text,
  property_id    text,
  offer_id       text,
  listing_id     text,
  viewing_id     text,
  tenancy_id     text,
  invoice_id     text,
  payment_id     text
);

create or replace function notifications_embeds_denormalize() returns trigger LANGUAGE PLPGSQL as $$
DECLARE
  t record;
BEGIN
  -- consult messaging proto's EmbedType for exact values
  for t in select jsonb_array_elements(NEW.event_embeds) val
  loop
     case
       when (t.val->'embed_type')::int = 1  then NEW.user_id     = t.val->>'embed_value';
       when (t.val->'embed_type')::int = 2  then NEW.property_id = t.val->>'embed_value';
       when (t.val->'embed_type')::int = 3  then NEW.offer_id    = t.val->>'embed_value';
       when (t.val->'embed_type')::int = 31 then NEW.listing_id  = t.val->>'embed_value';
       when (t.val->'embed_type')::int = 12 then NEW.viewing_id  = t.val->>'embed_value';
       when (t.val->'embed_type')::int = 25 then NEW.tenancy_id  = t.val->>'embed_value';
       when (t.val->'embed_type')::int = 29 then NEW.invoice_id  = t.val->>'embed_value';
       when (t.val->'embed_type')::int = 30 then NEW.payment_id  = t.val->>'embed_value';
       else
     end case;
  end loop;
  return NEW;
END
$$;

create trigger notifications_embeds_denormalize_insert before insert on notifications for each row execute procedure notifications_embeds_denormalize();
create trigger notifications_embeds_denormalize_update before update on notifications for each row execute procedure notifications_embeds_denormalize();
