alter table notifications rename to legacy_notification_logs;

drop function notifications_embeds_denormalize cascade;

create table notifications(
  id             bigserial primary key,
  actor          int4 not null,
  entity         int4 not null,
  role           int4 not null,
  action         int4 not null,
  duration       int8 not null,
  channel        int4 not null,
  template       text not null,
  template_html  boolean not null default false,
  data           jsonb not null default '{}',
  updated        timestamp not null default now(),
  created        timestamp not null default now(),
  disabled       boolean not null default false,
  customized     boolean not null default false,
  unique(actor, entity, role, action, duration, channel)
);

create table notification_logs(
  id              bigserial primary key,
  recipient       text,
  email           text,
  phone           text,
  actor           int4 not null,
  entity          int4 not null,
  role            int4 not null,
  action          int4 not null,
  duration        int8 not null,
  channel         int4 not null,
  embeds          jsonb not null,
  error           text,
  user_id         text,
  property_id     text,
  offer_id        text,
  listing_id      text,
  viewing_id      text,
  tenancy_id      text,
  invoice_id      text,
  payment_id      text,
  created         timestamp not null default now(),
  updated         timestamp not null default now(),
  processed       bool not null default false
);

create or replace function notification_logs_embeds_denormalize() returns trigger LANGUAGE PLPGSQL as $$
DECLARE
  t record;
BEGIN
  -- consult messaging proto's EmbedType for exact values
  for t in select jsonb_array_elements(NEW.embeds) val
  loop
     case
       when (t.val->'embed_type')::int = 1  then NEW.user_id     = t.val->>'embed_value';
       when (t.val->'embed_type')::int = 2  then NEW.property_id = t.val->>'embed_value';
       when (t.val->'embed_type')::int = 3  then NEW.offer_id    = t.val->>'embed_value';
       when (t.val->'embed_type')::int = 31 then NEW.listing_id  = t.val->>'embed_value';
       when (t.val->'embed_type')::int = 12 then NEW.viewing_id  = t.val->>'embed_value';
       when (t.val->'embed_type')::int = 25 then NEW.tenancy_id  = t.val->>'embed_value';
       when (t.val->'embed_type')::int = 29 then NEW.invoice_id  = t.val->>'embed_value';
       when (t.val->'embed_type')::int = 30 then NEW.payment_id  = t.val->>'embed_value';
       else
     end case;
  end loop;
  return NEW;
END
$$;


create trigger notification_logs_embeds_denormalize_insert before insert on notification_logs for each row execute procedure notification_logs_embeds_denormalize();
create trigger notification_logs_embeds_denormalize_update before update on notification_logs for each row execute procedure notification_logs_embeds_denormalize();
