package service

import (
	"context"

	"gitlab.mashroom.com/mashroom/backend/common/generic/log"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/handlers"
)

// polls single activity for execution
func (srv *serviceImpl) handlerDequeueNext(ctx context.Context, key string, handler handlers.Handler) {
	t, err := srv.config.Queue.TaskDequeue(ctx, key, handler.RetryPeriod())
	if err != nil {
		log.WithError(err).Errorf("dequeueing for key %s", key)
		return
	}

	if t == nil {
		return
	}

	ctx, cancel := context.WithTimeout(ctx, handler.RetryPeriod())

	defer cancel()

	err = handler.Run(ctx, t)

	var errstr string

	if err != nil {
		log.WithError(err).WithField("task", t).Errorf("invoking for key %s", key)

		errstr = err.Error()
	}

	err = srv.config.Repository.LogUpdateError(ctx, t.LogID, errstr)
	if err != nil {
		log.WithError(err).WithField("task", t).Errorf("updating notification log status")
	}

	err = srv.config.Queue.TaskAck(ctx, key, t.AckID)
	if err != nil {
		log.WithError(err).WithField("task", t).Errorf("acking for key %s", key)
	}
}

// polls activities for execution until parent context is cancelled
func (srv *serviceImpl) handlerDequeue(ctx context.Context, key string, handler handlers.Handler) {
	tick := srv.config.DequeueTicker(key)

	for {
		select {
		case <-ctx.Done():
			return
		case _, ok := <-tick:
			if !ok {
				return
			}

			srv.handlerDequeueNext(ctx, key, handler)
		}
	}
}
