// Package task provides abstraction for retriable tasks
package task

import (
	"context"
	"time"
)

// Repository for tasks
type Repository interface {
	// TaskDequeue returns next notification task for given handler prioritizing those that wasn't handled in time by
	// other instances of this service
	// May return nil if no tasks are pending at current moment
	TaskDequeue(ctx context.Context, handler string, retry time.Duration) (*Task, error)
	// TaskAck marks task as successfully processed
	TaskAck(ctx context.Context, handler string, ackid string) error
	// TaskEnqueue schedules task
	TaskEnqueue(ctx context.Context, handler string, task *Task) error
}
