package task

import (
	"encoding/json"

	messaging "gitlab.mashroom.com/mashroom/backend/messaging/api"
	notification "gitlab.mashroom.com/mashroom/backend/notification/api"
)

// Platform task
type Platform struct {
	UserID       string                         `json:"userID,omitempty"`
	Body         string                         `json:"body,omitempty"`
	Embeds       []*messaging.Embed             `json:"embeds,omitempty"`
	Event        int32                          `json:"event,omitempty"`
	Notification *notification.NotificationSpec `json:"notification,omitempty"`
	Title        string                         `json:"title,omitempty"`
}

// PlatformTaskOption api mutator
type PlatformTaskOption func(platformTask *Platform)

// WithPlatformEventType returns PlatformTaskOption providing event type ID
func WithPlatformEventType(evt notification.EventType) PlatformTaskOption {
	return func(t *Platform) {
		t.Event = int32(evt)
	}
}

// WithPlatformBody returns PlatformTaskOption providing message body
func WithPlatformBody(body string) PlatformTaskOption {
	return func(t *Platform) {
		t.Body = body
	}
}

// WithPlatformEmbeds returns PlatformTaskOption providing message embeds
func WithPlatformEmbeds(embeds []*notification.EventEmbed) PlatformTaskOption {
	var memb []*messaging.Embed

	for _, e := range embeds {
		memb = append(memb, &messaging.Embed{
			EmbedType:  int32(e.GetEmbedType()),
			EmbedValue: e.GetEmbedValue(),
		})
	}

	return func(t *Platform) {
		t.Embeds = memb
	}
}

// WithPlatformNotification returns PlatformTaskOption providing notification specification
func WithPlatformNotification(n *notification.NotificationSpec) PlatformTaskOption {
	return func(t *Platform) {
		t.Notification = n
	}
}

// WithPlatformTitle returns PlatformTaskOption providing notification title
func WithPlatformTitle(title string) PlatformTaskOption {
	return func(t *Platform) {
		t.Title = title
	}
}

// NewPlatform returns new platform task
func NewPlatform(user string, options ...PlatformTaskOption) *Task {
	t := &Platform{
		UserID: user,
	}

	for _, o := range options {
		o(t)
	}

	bs, _ := json.Marshal(t)

	return &Task{
		Data: bs,
	}
}
