// Package redis provides redis implementation for task queue
package redis

import (
	"context"
	"fmt"
	"strings"

	"github.com/go-redis/redis/v8"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/task"
)

const streamgroup = "notification"

// Config for redis repository
type Config struct {
	RedisClient *redis.Client // redis connection
	Consumer    string        // consumer ID
	Handlers    []string      // handler keys
}

func validateConfig(config *Config) error {
	if config == nil {
		return fmt.Errorf("invalid repository config")
	}

	if config.RedisClient == nil {
		return fmt.Errorf("no redis client in repository config")
	}

	if config.Consumer == "" {
		return fmt.Errorf("invalid consumer in repository config")
	}

	if len(config.Handlers) == 0 {
		return fmt.Errorf("no handlers in repository config")
	}

	return nil
}

// NewRepository creates new repository instance also initializing consumer group for all registered handlers
func NewRepository(ctx context.Context, config *Config) (task.Repository, error) {
	err := validateConfig(config)
	if err != nil {
		return nil, err
	}

	for _, k := range config.Handlers {
		streamkey := "notification:" + k + ":stream"

		err := config.RedisClient.XGroupCreateMkStream(ctx, streamkey, streamgroup, "$").Err()
		if err != nil && !strings.Contains(err.Error(), "BUSYGROUP") {
			return nil, err
		}
	}

	repo := &repositoryImpl{
		config: *config,
	}

	return repo, nil
}
