// Package root holds root of all notification templates
package root

import (
	notification "gitlab.mashroom.com/mashroom/backend/notification/api"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/template"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/document"
	documentExpiration "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/document/expiration"
	insuranceCiPayment "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/insurance/ci/payment"
	insuranceHeiPayment "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/insurance/hei/payment"
	insuranceRgiPayment "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/insurance/rgi/payment"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/message"
	mortgageNote "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/mortgage/note"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/offer"
	offerAdvance "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/offer/advance"
	offerClause "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/offer/clause"
	offerDeposited "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/offer/deposited"
	offerDepositReplacement "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/offer/depositreplacement"
	offerExtraPayment "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/offer/extra/payment"
	offerHoldingDepositPayment "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/offer/holdingdeposit/payment"
	offerOther "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/offer/other"
	offerReferenceChecks "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/offer/referencechecks"
	offerRenewal "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/offer/renewal"
	offerRentPayment "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/offer/rent/payment"
	offerSignature "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/offer/signature"
	offerSignatureInvitation "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/offer/signature/invitation"
	paymentInvoice "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/payment/invoice"
	paymentMandate "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/payment/mandate"
	paymentTransaction "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/payment/transaction"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property"
	propertyInvitation "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/invitation"
	propertyInvitationManager "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/invitation/manager"
	propertyInvitationManagerUnlisted "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/invitation/manager/unlisted"
	propertyIssue "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/issue"
	propertyIssueAssignContractor "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/issue/assign/contractor"
	propertyIssueAssignLocalheroes "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/issue/assign/localheroes"
	propertyListing "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/listing"
	propertyListingPayment "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/listing/payment"
	propertyPublication "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/publication"
	propertyQuestion "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/question"
	propertyTask "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/task"
	propertyTenancy "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/tenancy"
	propertyTenancyClaim "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/tenancy/claim"
	propertyTenancyClaimDispute "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/tenancy/claim/dispute"
	propertyTenancyClaimPayment "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/tenancy/claim/payment"
	propertyTenancyDeposit "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/tenancy/deposit"
	propertyTenancyTermination "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/tenancy/termination"
	propertyViewing "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/viewing"
	propertyViewingBroadcasting "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/viewing/broadcasting"
	propertyViewingFavorite "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/viewing/favorite"
	propertyViewingRarity "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/viewing/rarity"
	propertyViewingReschedule "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/viewing/reschedule"
	propertyViewingReward "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/property/viewing/reward"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/user"
	userEmail "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/user/email"
	userPassword "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/user/password"
	userPhone "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/user/phone"
	userSignin "gitlab.mashroom.com/mashroom/backend/notification/internal/template/root/user/signin"
)

// Registry map
var Registry = template.DescriptorMap{
	notification.Entity_ENTITY_OFFER:                                offer.Registry,
	notification.Entity_ENTITY_OFFER_CLAUSE:                         offerClause.Registry,
	notification.Entity_ENTITY_OFFER_SIGNATURE:                      offerSignature.Registry,
	notification.Entity_ENTITY_OFFER_SIGNATURE_INVITATION:           offerSignatureInvitation.Registry,
	notification.Entity_ENTITY_OFFER_HOLDING_DEPOSIT_PAYMENT:        offerHoldingDepositPayment.Registry,
	notification.Entity_ENTITY_OFFER_REFERENCE_CHECKS:               offerReferenceChecks.Registry,
	notification.Entity_ENTITY_OFFER_RENT_PAYMENT:                   offerRentPayment.Registry,
	notification.Entity_ENTITY_OFFER_RENT_ADVANCE:                   offerAdvance.Registry,
	notification.Entity_ENTITY_OFFER_DEPOSITED:                      offerDeposited.Registry,
	notification.Entity_ENTITY_OFFER_DEPOSIT_REPLACEMENT:            offerDepositReplacement.Registry,
	notification.Entity_ENTITY_OFFER_RENEWAL:                        offerRenewal.Registry,
	notification.Entity_ENTITY_OFFER_EXTRA_PAYMENT:                  offerExtraPayment.Registry,
	notification.Entity_ENTITY_OFFER_OTHER:                          offerOther.Registry,
	notification.Entity_ENTITY_PROPERTY:                             property.Registry,
	notification.Entity_ENTITY_PROPERTY_INVITATION:                  propertyInvitation.Registry,
	notification.Entity_ENTITY_PROPERTY_INVITATION_MANAGER:          propertyInvitationManager.Registry,
	notification.Entity_ENTITY_PROPERTY_INVITATION_MANAGER_UNLISTED: propertyInvitationManagerUnlisted.Registry,
	notification.Entity_ENTITY_PROPERTY_LISTING:                     propertyListing.Registry,
	notification.Entity_ENTITY_PROPERTY_LISTING_PAYMENT:             propertyListingPayment.Registry,
	notification.Entity_ENTITY_PROPERTY_VIEWING:                     propertyViewing.Registry,
	notification.Entity_ENTITY_PROPERTY_VIEWING_RARITY:              propertyViewingRarity.Registry,
	notification.Entity_ENTITY_PROPERTY_VIEWING_FAVORITE:            propertyViewingFavorite.Registry,
	notification.Entity_ENTITY_PROPERTY_VIEWING_RESCHEDULE:          propertyViewingReschedule.Registry,
	notification.Entity_ENTITY_PROPERTY_VIEWING_REWARD:              propertyViewingReward.Registry,
	notification.Entity_ENTITY_PROPERTY_VIEWING_BROADCASTING:        propertyViewingBroadcasting.Registry,
	notification.Entity_ENTITY_PROPERTY_TENANCY:                     propertyTenancy.Registry,
	notification.Entity_ENTITY_PROPERTY_TENANCY_CLAIM:               propertyTenancyClaim.Registry,
	notification.Entity_ENTITY_PROPERTY_TENANCY_CLAIM_DISPUTE:       propertyTenancyClaimDispute.Registry,
	notification.Entity_ENTITY_PROPERTY_TENANCY_CLAIM_PAYMENT:       propertyTenancyClaimPayment.Registry,
	notification.Entity_ENTITY_PROPERTY_TENANCY_TERMINATION:         propertyTenancyTermination.Registry,
	notification.Entity_ENTITY_PROPERTY_TENANCY_DEPOSIT:             propertyTenancyDeposit.Registry,
	notification.Entity_ENTITY_PROPERTY_ISSUE:                       propertyIssue.Registry,
	notification.Entity_ENTITY_PROPERTY_ISSUE_ASSIGN_CONTRACTOR:     propertyIssueAssignContractor.Registry,
	notification.Entity_ENTITY_PROPERTY_ISSUE_ASSIGN_LOCALHEROES:    propertyIssueAssignLocalheroes.Registry,
	notification.Entity_ENTITY_PROPERTY_TASK:                        propertyTask.Registry,
	notification.Entity_ENTITY_PROPERTY_PUBLICATION:                 propertyPublication.Registry,
	notification.Entity_ENTITY_PROPERTY_QUESTION:                    propertyQuestion.Registry,
	notification.Entity_ENTITY_INSURANCE_CI_PAYMENT:                 insuranceCiPayment.Registry,
	notification.Entity_ENTITY_INSURANCE_HEI_PAYMENT:                insuranceHeiPayment.Registry,
	notification.Entity_ENTITY_INSURANCE_RGI_PAYMENT:                insuranceRgiPayment.Registry,
	notification.Entity_ENTITY_USER:                                 user.Registry,
	notification.Entity_ENTITY_USER_PASSWORD:                        userPassword.Registry,
	notification.Entity_ENTITY_USER_EMAIL:                           userEmail.Registry,
	notification.Entity_ENTITY_USER_PHONE:                           userPhone.Registry,
	notification.Entity_ENTITY_USER_SIGNIN:                          userSignin.Registry,
	notification.Entity_ENTITY_MESSAGE:                              message.Registry,
	notification.Entity_ENTITY_PAYMENT_MANDATE:                      paymentMandate.Registry,
	notification.Entity_ENTITY_PAYMENT_INVOICE:                      paymentInvoice.Registry,
	notification.Entity_ENTITY_PAYMENT_TRANSACTION:                  paymentTransaction.Registry,
	notification.Entity_ENTITY_MORTGAGE_NOTE:                        mortgageNote.Registry,
	notification.Entity_ENTITY_DOCUMENT:                             document.Registry,
	notification.Entity_ENTITY_DOCUMENT_EXPIRATION:                  documentExpiration.Registry,
}
