// Package advance notification actions
package advance

import (
	notification "gitlab.mashroom.com/mashroom/backend/notification/api"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/template"
)

// Registry map
var Registry = template.ActionMap{
	notification.Action_ACTION_ACCEPT: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_ADVANCED_RENT_REQUEST_ACCEPTED_NOTIFY_LANDLORD:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-f834d039edef4c7ea0cd13a206808810"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`Congratulations! Your request to receive advanced rent has been accepted`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_ADVANCED_RENT_REQUEST_ACCEPTED_NOTIFY_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-90f224dd344a41189c59c94478ffa973"),
				),
			),
		),
	),
	notification.Action_ACTION_CANCEL: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_UNKNOWN,
			notification.Role_ROLE_ADMIN,
			// notification.EventType_EVENT_ADVANCED_RENT_REQUEST_CANCELLED_NOTIFY_ADMIN:
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_EMAIL,
				template.WithSubject(
					`A request for advanced rent has been cancelled`,
				),
				template.WithGoTemplate(
					`{{.user.name}} has cancelled their request for advanced rent for {{.property.name}}<br>`+
						`Postcode: {{.property.location.postcode}}<br>`+
						`Landlord: {{.user.name}}`,
				),
			),
		),
	),
	notification.Action_ACTION_COMPLETE: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_ADMIN,
				// notification.EventType_EVENT_ADVANCED_RENT_PAYMENT_CONFIRMED_NOTIFY_ADMIN:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSubject(
						`A request for advanced rent has been sent`,
					),
					template.WithGoTemplate(
						`The advanced rent has been paid to the landlord’s bank account for {{.property.name}}<br>`+
							`Postcode: {{.property.location.postcode}}<br>`+
							`Landlord: {{.user.name}}`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_ADVANCED_RENT_PAYMENT_CONFIRMED_NOTIFY_LANDLORD:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-882f8481e8f94dd693ed6da24087c175"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`Your Mashroom advanced rent payment has been paid to your bank account.`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`Your advanced rent payment has been paid to your bank account.`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_CREATE: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_UNKNOWN,
			notification.Role_ROLE_ADMIN,
			// notification.EventType_EVENT_ADVANCED_RENT_REQUEST_CREATED_NOTIFY_ADMIN:
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_EMAIL,
				template.WithSubject(
					`New request for advanced rent`,
				),
				template.WithGoTemplate(
					`{{.user.name}} has made a request for advanced rent for {{.property.name}}<br>`+
						`Postcode: {{.property.location.postcode}}<br>`+
						`Landlord: {{.user.name}}`,
				),
			),
		),
	),
	notification.Action_ACTION_REJECT: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_UNKNOWN,
			notification.Role_ROLE_LANDLORD,
			// notification.EventType_EVENT_ADVANCED_RENT_REQUEST_DENIED_NOTIFY_LANDLORD:
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_EMAIL,
				template.WithSendgridTemplate("d-6b2369a53ac94edbb92813240255b058"),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_PLATFORM,
				template.WithGoTemplate(
					`Your request to receive advanced rent has been denied`,
				),
			),
		),
	),
}
