// Package offer notification actions
package offer

import (
	"time"

	notification "gitlab.mashroom.com/mashroom/backend/notification/api"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/template"
)

// Registry map
var Registry = template.ActionMap{
	notification.Action_ACTION_ACCEPT: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_OFFER_ACCEPTED_CONFIRM_LANDLORD:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-aa6b339527af4c07b0f98f6c3e22d394"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`Thank you for accepting offer. What are the next steps? `+
							`Applicant now has 24 hours to pay their holding deposit`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_OFFER_ACCEPT_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-2ff325b2b5f24506be3e79ac643e4d44"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`Congratulations your offer has been accepted, you now need to pay the holding `+
							`deposit within 24hrs`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Offer Accepted`,
					),
					template.WithGoTemplate(
						`Great news! Your offer has been accepted.`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_CANCEL: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_OFFER_ACCEPTED_WITHDRAWN_NOTIFY_LANDLORD:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-56e3b2224f634f2dabb3960bf62ba0cb"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`A potential tenant has withdrawn their offer. You can now accept another offer`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_OFFER_ACCEPTED_WITHDRAWN_CONFIRM_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-4499bb478e3a4cd19b4e24260f1afb17"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Offer Withdrawn`,
					),
					template.WithGoTemplate(
						`You have withdrawn your offer. We will update the landlord`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_COMPLETE: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_OFFER_JOURNEY_COMPLETE_NOTIFY_LANDLORD:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-e8153e53113c4dc1aebcf5291fae7b62"),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_PAYMENT_READY_MOVEIN_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-28b8ced701b24db2a4fac7263dd83062"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`Hi {{.recipient.name}},

We have amazing news!

You can now move into your new home. `+
							`Please contact your landlord via the chat on Mashroom to arrange for key collection.`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Move in`,
					),
					template.WithGoTemplate(
						`Hi {{.recipient.name}},

We have amazing news!

You can now move into your new home. Please message your landlord to arrange for key collection.
We hope you enjoy your new home.`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_CREATE: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_OFFER_REQUEST_MANAGER:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-e982b7eaf4b3411b9b82dcd7a24dcab3"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`Great news {{.recipient.name}}! You have received an offer for your property `+
							`{{.property.name}}!`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Offer Request`,
					),
					template.WithGoTemplate(
						`You've received an offer for {{.property.name}}`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_OFFER_SENT_CONFIRM_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`Your offer has been submitted to landlord`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_PENDING: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_UNKNOWN,
			notification.Role_ROLE_LANDLORD,
			template.WithDuration(
				time.Hour*3,
				// notification.EventType_EVENT_OFFER_RECEIVED_NOT_RESPONDED_REMIND_LANDLORD_3HRS:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-14d2b5fef840496fa3b71ea280233fb4"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`You have an offer for {{.property.name}} on Mashroom that is awaiting your response! `+
							`You can accept the offer or negotiate with the tenant by following this link: `+
							`{{.site}}/dashboard/{{.property.id}}/overview`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`You have an outstanding offer for a property that you still need to respond to`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_REJECT: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_OFFER_REJECTED_CONFIRM_LANDLORD:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`You have declined the applicants offer`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_OFFER_REJECTED_NOTIFY_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-7c93d59d76104b6fb920608625ec576b"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`Your offer has been rejected by the landlord. `+
							`Message them through the platform to negotiate and make another offer!`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Offer Declined`,
					),
					template.WithGoTemplate(
						`Your offer has been rejected by the landlord`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_REMIND: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				template.WithDuration(
					time.Hour*24*7,
					// notification.EventType_EVENT_OFFER_RECEIVED_NOT_RESPONDED_REMIND_LANDLORD_1WEEK_LEFT:
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_EMAIL,
						template.WithSendgridTemplate("d-1cce72b3780d4bb5a2f42d94324b1b08"),
					),
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_SMS,
						template.WithGoTemplate(
							`Proposed move in date fast approaching (1 week away)- `+
								`you need to accept/decline the tenants offer or contact them via the chat service`,
						),
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				template.WithDuration(
					time.Hour*24*7,
					// notification.EventType_EVENT_OFFER_RECEIVED_NOT_RESPONDED_REMIND_TENANT_1WEEK_LEFT:
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_EMAIL,
						template.WithSendgridTemplate("d-1cce72b3780d4bb5a2f42d94324b1b08"),
					),
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_SMS,
						template.WithGoTemplate(
							`The landlord has not yet responded to your offer (with 1 week left until `+
								`move in date). `+
								`Your proposed move in date is fast approaching, `+
								`why not get in contact with the landlord or update your move in date`,
						),
					),
				),
			),
		),
	),
	notification.Action_ACTION_UPDATE: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_UNKNOWN,
			notification.Role_ROLE_LANDLORD,
			// notification.EventType_EVENT_OFFER_UPDATE_MANAGER:
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_EMAIL,
				template.WithSendgridTemplate("d-4f95459e2a7547bca8e2ac251283c70c"),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_SMS,
				template.WithTitle(
					`Offer Update`,
				),
				template.WithGoTemplate(
					`The potential tenant has updated their offer. `+
						`Please log in to your dashboard to see the updated terms`,
				),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_PLATFORM,
				template.WithGoTemplate(
					`A potential tenant has updated their offer`,
				),
			),
		),
	),
}
