// Package clause notification actions
package clause

import (
	notification "gitlab.mashroom.com/mashroom/backend/notification/api"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/template"
)

// Registry map
var Registry = template.ActionMap{
	notification.Action_ACTION_ACCEPT: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_UNKNOWN,
			notification.Role_ROLE_LANDLORD,
			// notification.EventType_EVENT_CONTRACT_CLAUSE_ACCEPT_LANDLORD:
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_EMAIL,
				template.WithSendgridTemplate("d-f77cfdcd1c2b480abd6eb2d52b65aa11"),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_SMS,
				template.WithGoTemplate(
					`Hi {{.recipient.details.first_name}}, the applicant, {{.user.name}}, `+
						`has accepted some of your clauses. `+
						`Please log into your Mashroom account to check the status and proceed to signing.`,
				),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_PLATFORM,
				template.WithGoTemplate(
					`The Tenant has responded to some of your clauses!`,
				),
			),
		),
	),
	notification.Action_ACTION_CREATE: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_ADMIN,
				// notification.EventType_EVENT_CONTRACT_LANDLORD_CLAUSE_CREATED_NOTIFY_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSubject(
						`A Landlord has added/editted a clause`,
					),
					template.WithGoTemplate(
						`The landlord for {{.property.name}} has added a clause to their contract. `+
							`{{.site}}/#/offers/{{.offer.id}}/edit`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_CONTRACT_CLAUSE_CREATED_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-0a6afd891b134ee2a0758d7bbac48137"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`The Landlord has made an update to the clauses in your contract - `+
							`please review and respond`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`The Landlord has made an update to the clauses in your contract - `+
							`please review and respond`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_REJECT: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_UNKNOWN,
			notification.Role_ROLE_LANDLORD,
			// notification.EventType_EVENT_CONTRACT_CLAUSE_REJECT_LANDLORD:
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_EMAIL,
				template.WithSendgridTemplate("d-ae1897bd91414d558c5236abb69da9de"),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_SMS,
				template.WithGoTemplate(
					`Hi {{.recipient.details.first_name}}, the applicant, {{.user.name}}, `+
						`has rejected some of your clauses. `+
						`You can message the applicant directly by logging into your dashboard.`,
				),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_PLATFORM,
				template.WithGoTemplate(
					`The Tenant has responded to some of your clauses!`,
				),
			),
		),
	),
	notification.Action_ACTION_REMOVE: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_UNKNOWN,
			notification.Role_ROLE_TENANT,
			// notification.EventType_EVENT_CONTRACT_CLAUSE_DELETED_TENANT:
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_EMAIL,
				template.WithSendgridTemplate("d-0a6afd891b134ee2a0758d7bbac48137"),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_SMS,
				template.WithGoTemplate(
					`The Landlord has made an update to the clauses in your contract - please review and respond`,
				),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_PLATFORM,
				template.WithGoTemplate(
					`The Landlord has made an update to the clauses in your contract - please review and respond`,
				),
			),
		),
	),
	notification.Action_ACTION_UPDATE: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_ADMIN,
				// notification.EventType_EVENT_CONTRACT_LANDLORD_CLAUSE_EDITED_NOTIFY_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSubject(
						`A Landlord has added/editted a clause`,
					),
					template.WithGoTemplate(
						`The landlord for {{.property.name}} has added a clause to their contract. `+
							`{{.site}}/#/offers/{{.offer.id}}/edit`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_CONTRACT_CLAUSE_EDITED_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-0a6afd891b134ee2a0758d7bbac48137"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`The Landlord has made an update to the clauses in your contract - `+
							`please review and respond`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`The Landlord has made an update to the clauses in your contract - `+
							`please review and respond`,
					),
				),
			),
		),
	),
}
