// Package payment notification actions
package payment

import (
	"time"

	notification "gitlab.mashroom.com/mashroom/backend/notification/api"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/template"
)

// Registry map
var Registry = template.ActionMap{
	notification.Action_ACTION_COMPLETE: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_OFFER_HOLDING_DEPOSIT_CONFIRM_MANAGER:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-477e68dedb514bc498b72e244e5d72ff"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`Good news {{.recipient.name}}! We are processing the holding deposit!`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Holding Deposit`,
					),
					template.WithGoTemplate(
						`The holding deposit for {{.property.name}} has been paid.`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_OFFER_HOLDING_DEPOSIT_CONFIRM_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-297a62c318f0445aa0c35977ac7b8d67"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`Thank you {{.recipient.name}}. Your holding deposit has been processed`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Holding Deposit`,
					),
					template.WithGoTemplate(
						`Your holding deposit has been processed.`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_EXPIRE: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_OFFER_HOLDING_DEPOSIT_NOT_PAID_MANAGER:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-1e04fa8f31d543b0aa95b1b26c4f2569"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Holding Deposit`,
					),
					template.WithGoTemplate(
						`The holding deposit was not paid in time, you can ask the tenant to submit another offer`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_OFFER_HOLDING_DEPOSIT_NOT_PAID_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSubject(
						`Holding deposit was not paid in time`,
					),
					template.WithGoTemplate(
						`Hi {{.recipient.name}},
<br>
<br>
Unfortunately your time to pay the holding deposit {{.property.name}} has passed.
<br>
<br>
But don't worry. You can make log into your dashboard and make an updated offer, which would need to be accepted again.
<br>
<br>
Kind Regards,
<br>
Team mashroom
<br>`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Holding Deposit`,
					),
					template.WithGoTemplate(
						`The holding deposit was not paid in time. Click here for details and action.`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_REMIND: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_UNKNOWN,
			notification.Role_ROLE_TENANT,
			template.WithDuration(
				time.Hour*12,
				// notification.EventType_EVENT_HOLDING_DEPOSIT_12HOURS_REMIND_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-d9c30fcb10ae4074a0f977ddd35ddf30"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`You still haven't paid your holding deposit.`+
							` You now have 12 hours left before the time to pay is up and your offer expires`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Holding Deposit`,
					),
					template.WithGoTemplate(
						`You still haven't paid your holding deposit.`+
							` You now have 12 hours left before the time to pay is up and your offer expires`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_CREATE: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_HOLDING_DEPOSIT_BANK_VERIFYING_PAYMENT_NOTIFY_LANDLORD::
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-1144fd57bbce48e2891e6efc55097f58"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Holding Deposit`,
					),
					template.WithGoTemplate(
						`The tenant has paid their holding deposit and the payment is being reconciled.`+
							` We will update you accordingly.`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_HOLDING_DEPOSIT_BANK_VERIFYING_PAYMENT_NOTIFY_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-f2e1d38c319a4fe89dc256e2339f8ebf"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Holding Deposit`,
					),
					template.WithGoTemplate(
						`Thank you for paying the holding deposit - a member of the team `+
							`will verify your payment.`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_VERIFY: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_HOLDING_DEPOSIT_BANK_CONFIRM_PAYMENT_NOTIFY_LANDLORD:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-3ea5f94d08bc4ee5a91d2f0b53ce2cb1"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Holding Deposit`,
					),
					template.WithGoTemplate(
						`The tenants holding deposit has now been successfully verified.`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_HOLDING_DEPOSIT_BANK_CONFIRM_PAYMENT_NOTIFY_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-0c69f7cd89114e16b576b55bb8250498"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Holding Deposit`,
					),
					template.WithGoTemplate(
						`Your holding deposit has now been successfully verified. Thank you.`,
					),
				),
			),
		),
	),
}
