// Package invitation notification actions
package invitation

import (
	"time"

	notification "gitlab.mashroom.com/mashroom/backend/notification/api"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/template"
)

// Registry map
var Registry = template.ActionMap{
	notification.Action_ACTION_PENDING: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_LANDLORD,
			notification.Role_ROLE_TENANT,
			// notification.EventType_EVENT_CONTRACT_LANDLORD_PROCEEDED_NOTIFY_TENANT:
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_EMAIL,
				template.WithSendgridTemplate("d-c677d9e3d82a43efbf684fda617efffb"),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_SMS,
				template.WithGoTemplate(
					`Hi {{.recipient.details.first_name}},`+
						` the landlord for {{.property.name}} is ready to sign the contract.`+
						` If you haven’t already please proceed to signing in your dashboard by clicking here.`,
				),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_PLATFORM,
				template.WithGoTemplate(
					`Hi {{.recipient.details.first_name}},`+
						` the landlord for {{.property.name}} is ready to sign the contract.`+
						` If you haven’t already please proceed to signing in your dashboard by clicking here.`,
				),
			),
			template.WithDuration(
				time.Hour*2,
				// notification.EventType_EVENT_CONTRACT_LANDLORD_PROCEEDED_REMIND_TENANT_2HOURS:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-e2eb41d04a3344e58a8d731553ffcdc2"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`Hi {{.recipient.details.first_name}},`+
							` the landlord for {{.property.name}} is waiting for your response.`+
							` Please proceed to signing as soon as possible by clicking here.`+
							` Alternatively, you can contact the landlord directly if you have any questions.`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`Hi {{.recipient.details.first_name}},`+
							` the landlord for {{.property.name}} is waiting for your response.`+
							` Please proceed to signing as soon as possible by clicking here.`+
							` Alternatively, you can contact the landlord directly if you have any questions.`,
					),
				),
			),
		),
		template.WithActorRole(
			notification.Role_ROLE_TENANT,
			notification.Role_ROLE_LANDLORD,
			// notification.EventType_EVENT_CONTRACT_TENANT_PROCEEDED_NOTIFY_LANDLORD:
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_EMAIL,
				template.WithSendgridTemplate("d-1ef5b6098d13498aab29c0ac6036553a"),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_SMS,
				template.WithGoTemplate(
					`Hi {{.recipient.details.first_name}},`+
						` the tenant for {{.property.name}} is ready to sign the contract.`+
						` If you haven’t already please proceed to signing in your dashboard by clicking here.`,
				),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_PLATFORM,
				template.WithGoTemplate(
					`Hi {{.recipient.details.first_name}},`+
						` the tenant for {{.property.name}} is ready to sign the contract.`+
						` If you haven’t already please proceed to signing in your dashboard by clicking here.`,
				),
			),
			template.WithDuration(
				time.Hour*2,
				// notification.EventType_EVENT_CONTRACT_TENANT_PROCEEDED_REMIND_LANDLORD_2HOURS:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-7c28a4a77c50465dbf4eac1c4bdba4ac"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`Hi {{.recipient.details.first_name}},`+
							` the tenant for {{.property.name}} is waiting for your response.`+
							` Please proceed to signing as soon as possible by clicking here.`+
							` Alternatively, you can contact the landlord directly if you have any questions`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`Hi {{.recipient.details.first_name}},`+
							` the tenant for {{.property.name}} is waiting for your response.`+
							` Please proceed to signing as soon as possible by clicking here.`+
							` Alternatively, you can contact the landlord directly if you have any questions`,
					),
				),
			),
		),
	),
}
