// Package manager notification actions
package manager

import (
	"time"

	notification "gitlab.mashroom.com/mashroom/backend/notification/api"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/template"
)

// Registry map
var Registry = template.ActionMap{
	notification.Action_ACTION_ACCEPT: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_LANDLORD,
			notification.Role_ROLE_LANDLORD,
			// notification.EventType_EVENT_TEAMUP_LANDLORD_ACCEPTS_VIEWING_HOST_NOTIFY_LANDLORD
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_PLATFORM,
				template.WithGoTemplate(
					`You have accepted the tenants invite to host viewings through team up.`,
				),
			),
		),
		template.WithActor(
			notification.Role_ROLE_TENANT,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_TEAMUP_TENANT_ACCEPTS_VIEWING_HOST_NOTIFY_LANDLORD
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-dc32f6beaaf34bd283214494fbdd3f44"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`Your current tenant has accepted your invite for them to host viewings through team up.`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_TEAMUP_TENANT_ACCEPTS_VIEWING_HOST_NOTIFY_TENANT
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`You have accepted the landlords invite to host viewings through team up.`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_CANCEL: template.Action(
		template.WithActor(
			notification.Role_ROLE_LANDLORD,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_TEAMUP_LANDLORD_END_VIEWING_HOST_NOTIFY_LANDLORD
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`You have requested that the tenant is no longer viewings host.`+
							` You will now be responsible for hosting viewings for this property.`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_TEAMUP_LANDLORD_END_VIEWING_HOST_NOTIFY_TENANT
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-44e92ccece734c39a14ae5549983c60f"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`The landlord has requested that you no longer host viewings at this property.`+
							` The landlord is now responsible for hosting viewings.`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`The landlord has requested that you no longer host viewings at this property.`+
							` The landlord is now responsible for hosting viewings.`,
					),
				),
			),
		),
		template.WithActor(
			notification.Role_ROLE_TENANT,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_TEAMUP_TENANT_REQUESTS_END_VIEWING_HOST_NOTIFY_LANDLORD
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-d97b3dd201f84573be25a8497bb44c3f"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`Your tenant is no longer viewings host. They have requested to stop.`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_TEAMUP_TENANT_REQUESTS_END_VIEWING_HOST_NOTIFY_TENANT
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-2739710710734ff8932c3788fe6028dd"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`We have notified the landlord that you no longer wish to be viewings `+
							`host through team up.`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_CREATE: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_TENANT,
			notification.Role_ROLE_TENANT,
			// notification.EventType_EVENT_TEAMUP_TENANT_INVITES_LANDLORD_NOTIFY_TENANT
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_PLATFORM,
				template.WithGoTemplate(
					`Your invite to host viewings has been sent to the landlord. We will notify you when they reply.`,
				),
			),
		),
		template.WithActorRole(
			notification.Role_ROLE_LANDLORD,
			notification.Role_ROLE_TENANT,
			// notification.EventType_EVENT_INVITATION_CREATE:
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_EMAIL,
				template.WithSendgridTemplate("d-11751e62bd4f4e34a76a1a4b420b0725"),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_PLATFORM,
				template.WithGoTemplate(
					`Your landlord {{.user.name}} has invited you to help with viewings.`,
				),
			),
		),
	),
	notification.Action_ACTION_REJECT: template.Action(
		template.WithActor(
			notification.Role_ROLE_LANDLORD,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_TEAMUP_LANDLORD_DECLINES_VIEWING_HOST_NOTIFY_LANDLORD
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`You have declined the tenants invite to host viewings through team up.`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_TEAMUP_LANDLORD_DECLINES_VIEWING_HOST_NOTIFY_TENANT
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-5e2b3fa7119d4e6ca3473ffab8393f3f"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`The landlord has declined your invite to host viewings through team up.`,
					),
				),
			),
		),
		template.WithActorRole(
			notification.Role_ROLE_TENANT,
			notification.Role_ROLE_LANDLORD,
			// notification.EventType_EVENT_TEAMUP_TENANT_DECLINES_VIEWING_HOST_NOTIFY_LANDLORD
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_EMAIL,
				template.WithSendgridTemplate("d-7265f9c6ed6a49139016abcbd445cf77"),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_PLATFORM,
				template.WithGoTemplate(
					`The tenant has declined your invite for them to host viewings.`,
				),
			),
		),
	),
	notification.Action_ACTION_REMIND: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_TENANT,
			notification.Role_ROLE_LANDLORD,
			template.WithDuration(
				time.Hour*24,
				// notification.EventType_EVENT_TEAMUP_TENANT_INVITES_24HOUR_REMINDER_LANDLORD
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`Please respond to your current tenant’s outstanding request`+
							` to become viewing host for your property.`,
					),
				),
			),
		),
	),
}
