// Package issue notification actions
package issue

import (
	notification "gitlab.mashroom.com/mashroom/backend/notification/api"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/template"
)

// Registry map
var Registry = template.ActionMap{
	notification.Action_ACTION_COMPLETE: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_UNKNOWN,
			notification.Role_ROLE_TENANT,
			// notification.EventType_EVENT_MAINTENANCE_RESOLVED:
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_EMAIL,
				template.WithSendgridTemplate("d-1151f34bc85e490db733fdb24d36db0f"),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_SMS,
				template.WithGoTemplate(
					`Hi {{.recipient.name}}. Maintenance issue resolved {{.maintenance.id}}.`,
				),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_PLATFORM,
				template.WithTitle(
					`Maintenance`,
				),
				template.WithGoTemplate(
					`A maintenance issue has been resolved for {{.property.name}}.`,
				),
			),
		),
	),
	notification.Action_ACTION_CREATE: template.Action(
		template.WithActor(
			notification.Role_ROLE_LANDLORD,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_MAINTENANCE_LANDLORD_CREATES_ISSUE_NOTIFY_LANDLORD:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Maintenance`,
					),
					template.WithGoTemplate(
						`Thank you for adding a maintenance ticket. We’ve notified the tenant.`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_MAINTENANCE_LANDLORD_CREATES_ISSUE_NOTIFY_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-ec14f7bf796641ca92db29bd6cbf746d"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`Your landlord has just created a maintenance ticket. Visit the property `+
							`dashboard to view the issue.`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Maintenance`,
					),
					template.WithGoTemplate(
						`Your landlord has created a maintenance ticket.`,
					),
				),
			),
		),
		template.WithActor(
			notification.Role_ROLE_TENANT,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_MAINTENANCE_TENANT_CREATES_ISSUE_NOTIFY_LANDLORD:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-f4c757f6616e4205bd752b85b7bf876e"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`Your tenant has created a maintenance request for {{.property.name}}.`+
							` Head to your dashboard to view the request.`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Maintenance`,
					),
					template.WithGoTemplate(
						`Your tenant has created a maintenance request for {{.property.name}}.`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_MAINTENANCE_TENANT_CREATES_ISSUE_NOTIFY_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Maintenance`,
					),
					template.WithGoTemplate(
						`Thank you for adding a maintenance ticket. We’ve notified the landlord.`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_UPDATE: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_MAINTENANCE_UPDATE_LANDLORD:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-aed827f1b5ed425b9d6129c901ab2cca"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`Hi {{.recipient.name}}. Your tenant has added an update to the maintenance `+
							`issue at {{.property.name}}.`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Maintenance`,
					),
					template.WithGoTemplate(
						`A maintenance issue has been updated for {{.property.name}}.`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_MAINTENANCE_UPDATE_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-afddf35069f84410923e805ca9a7915f"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`Hi {{.recipient.name}}. Your landlord has added an update to the maintenance `+
							`issue at {{.property.name}}.`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Maintenance`,
					),
					template.WithGoTemplate(
						`Your landlord has updated a maintenance issue.`,
					),
				),
			),
		),
	),
}
