// Package listing notification actions
package listing

import (
	"time"

	notification "gitlab.mashroom.com/mashroom/backend/notification/api"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/template"
)

// Registry map
var Registry = template.ActionMap{
	notification.Action_ACTION_COMPLETE: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_MANAGER,
				// notification.EventType_EVENT_PROPERTY_MANAGE_VIEWING_BY_LANDLORD_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate(`d-715b75d1bab64a72bd95cfe32bbc7335`),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`New Listing`,
					),
					template.WithGoTemplate(
						`The landlord {{.user.name}} you invited has now listed their property with Mashroom.com`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_PROPERTY_MANAGE_VIEWING_BY_LANDLORD_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate(`d-42f3d11683444c7ca8d7b157d8436e3f`),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`New Listing`,
					),
					template.WithGoTemplate(
						`The landlord {{.user.name}} you invited has now listed their property with Mashroom.com`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_PENDING: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_LISTING_AWAITING_VERIFICATION_LANDLORD:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate(`d-f5564e0e53564eac980baca11db36efb`),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`New Listing`,
					),
					template.WithGoTemplate(
						`Your property listing is being verified by our team. `+
							`We will notify you when the listing goes live`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_ADMIN,
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSubject("A mashroom property requires verification"),
					template.WithGoTemplate(
						`Hi there, the following property requires verification through the admin tool:`+
							`<br>{{.property.name}}<br>`+
							`please log into the admin tool to check this Listing<br>`+
							`<a href=\"{{.adminsite}}\">{{.adminsite}}</a>`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_REMIND: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_UNKNOWN,
			notification.Role_ROLE_LANDLORD,
			template.WithDuration(
				time.Hour*6,
				// notification.EventType_EVENT_PROPERTY_INCOMPLETE_SIX_HOUR_LANDLORD:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate(`d-3544ec2df91248c89e5accf18d0abcb4`),
				),
			),
			template.WithDuration(
				time.Hour*24,
				// notification.EventType_EVENT_PROPERTY_INCOMPLETE_ONE_DAY_LANDLORD:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate(`d-7190599402ef4c8d9492d055fe547ef0`),
				),
			),
			template.WithDuration(
				time.Hour*72,
				// notification.EventType_EVENT_PROPERTY_INCOMPLETE_THREE_DAYS_LANDLORD:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate(`d-0d89918eafa64b1eac1264620ca5d16e`),
				),
			),
		),
	),
}
