// Package publication notification actions
package publication

import (
	notification "gitlab.mashroom.com/mashroom/backend/notification/api"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/template"
)

// Registry map
var Registry = template.ActionMap{
	notification.Action_ACTION_CANCEL: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_PROPERTY_WITHDRAWN:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSubject(
						`Property has been withdrawn`,
					),
					template.WithGoTemplate(
						`Hello {{.user.name}}, <br> As requested,`+
							` the following property listing has been withdrawn from mashroom,`+
							` Rightmove and Zoopla. <br> {{.property.name}} <br> We have saved all your property details,`+
							` so if you wish to re-list your property at any point, you can go to your Listings dashboard`+
							` and click ‘Relist property’. This will submit your property to our team for verification`+
							` and we will get your property live again once we have checked all the details.`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`Your property has been withdrawn from mashroom, Rightmove and Zoopla.`+
							` You can re-list your property from your Listings dashboard.`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_ADMIN,
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSubject(
						`The property has been withdrawn`,
					),
					template.WithGoTemplate(
						`The following property has been withdrawn from mashroom, Rightmove and Zoopla.<br>`+
							` Property: {{.property.name}} <br> Landlord: {{.user.name}}`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_CREATE: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_UNKNOWN,
			notification.Role_ROLE_MANAGER,
			// notification.EventType_EVENT_PROPERTY_PUBLISHED_MANAGER:
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_EMAIL,
				template.WithSendgridTemplate("d-b0635fcded6b42cc842785663f030a02"),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_SMS,
				template.WithGoTemplate(
					`Hi {{.recipient.name}},

Brilliant, your property has been published and is live on Zoopla and Rightmove. 

Please login to your dashboard to start arranging viewings.`,
				),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_PLATFORM,
				template.WithGoTemplate(
					`{{.property.name}} is now live.`,
				),
			),
		),
	),
}
