// Package claim notification actions
package claim

import (
	notification "gitlab.mashroom.com/mashroom/backend/notification/api"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/template"
)

// Registry map
var Registry = template.ActionMap{
	notification.Action_ACTION_ACCEPT: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_UNKNOWN,
			notification.Role_ROLE_LANDLORD,
			// notification.EventType_EVENT_OFFER_TENANCY_TERMINATE_CLAIM_AGREE_NOTIFY_LANDLORD:
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_EMAIL,
				template.WithSendgridTemplate("d-8dff5536b99d4360a2c861fd286e4b0b"),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_PLATFORM,
				template.WithGoTemplate(
					`Your tenant has accepted all outstanding claims.`,
				),
			),
		),
	),
	notification.Action_ACTION_COMPLETE: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_OFFER_TENANCY_CLAIM_END_NOTIFY_LANDLORD:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSubject(
						`End of post-tenancy claim period`,
					),
					template.WithGoTemplate(
						`Hi {{.recipient.name}}! Tenancy for {{.property.name}} and claim period has ended.`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`Claim period for tenancy has ended`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
			),
		),
	),
	notification.Action_ACTION_CREATE: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_OFFER_TENANCY_TERMINATE_CLAIM_RAISED_CONFIRM_LANDLORD:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-d3677ae96ee14bbaa57c6abbba0f7d03"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`We have sent the claim details to the tenant`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_OFFER_TENANCY_TERMINATE_CLAIM_RAISED_NOTIFY_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-3e473f4af2934678a86e1fe7e851557d"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`Your landlord has raised a claim. Visit the property dashboard to respond.`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_EXPIRE: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_ADMIN,
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSubject(
						`The 10 day period for a property has ended`,
					),
					template.WithGoTemplate(
						`the landlord for {{.property.name}} has not raised any claims within 10 days, `+
							`please contact an admin to release the deposit if necessary`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_OFFER_TENANCY_TERMINATE_NO_CLAIMS_NOTIFY_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-d51fc6e762a04318b4dcb81708ba5ecc"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`Your deposit has been released.`,
					),
				),
			),
		),
	),
}
