// Package dispute notification actions
package dispute

import (
	"time"

	notification "gitlab.mashroom.com/mashroom/backend/notification/api"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/template"
)

// Registry map
var Registry = template.ActionMap{
	notification.Action_ACTION_CREATE: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				// notification.EventType_EVENT_OFFER_TENANCY_TERMINATE_CLAIM_DISPUTED_NOTIFY_LANDLORD:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-ab597f028e7746dc908c8a4df1949909"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`A tenant has disputed your claims, discuss through the messenger if necessary.`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_OFFER_TENANCY_TERMINATE_CLAIM_DISPUTED_NOTIFY_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-30aac4648b0f44758cc12fcef3593e4c"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`We have notified the landlord that you would like to dispute the claims process.`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_REMIND: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_LANDLORD,
				template.WithDuration(
					time.Hour*24*5,
					// notification.EventType_EVENT_OFFER_TENANCY_TERMINATE_CLAIM_DISPUTED_LAST_CHANCE_NOTIFY_LANDLORD:
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_EMAIL,
						template.WithSendgridTemplate("d-5d65cfe2539b410ebfdf13019f4e9e9b"),
					),
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_PLATFORM,
						template.WithGoTemplate(
							`Last chance to settle your claims before they are taken to adjudication`,
						),
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_ADMIN,
				template.WithDuration(
					time.Hour*48,
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_EMAIL,
						template.WithSubject(
							`landlord claim at end of tenancy requires tenant response`,
						),
						template.WithGoTemplate(
							`the tenant for {{.property.name}} hasn't responded to their landlord’s claim on `+
								`a property in 2 days please follow up with the tenant and landlord.`,
						),
					),
				),
				template.WithDuration(
					time.Hour*24*5,
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_EMAIL,
						template.WithSubject(
							`landlord claim at end of tenancy requires tenant response`,
						),
						template.WithGoTemplate(
							`the tenant for {{.property.name}} hasn't responded to their landlord’s claim on `+
								`a property in 5 days please follow up with the tenant and landlord.`,
						),
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				template.WithDuration(
					time.Hour*24,
					// notification.EventType_EVENT_OFFER_TENANCY_TERMINATE_CLAIM_DISPUTED_1DAY_NOTIFY_TENANT:
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_EMAIL,
						template.WithSendgridTemplate("d-2ea555d9200742fc8757fa5da7d7ba37"),
					),
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_PLATFORM,
						template.WithGoTemplate(
							`Last chance to settle your claims before they are taken to adjudication`,
						),
					),
				),
				template.WithDuration(
					time.Hour*48,
					// notification.EventType_EVENT_OFFER_TENANCY_TERMINATE_CLAIM_DISPUTED_2DAY_NOTIFY_TENANT:
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_EMAIL,
						template.WithSendgridTemplate("d-5ed3fa216fdf4e74b3720964a0a0de53"),
					),
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_PLATFORM,
						template.WithGoTemplate(
							`Last chance to settle your claims before they are taken to adjudication.`,
						),
					),
				),
				template.WithDuration(
					time.Hour*24*5,
					// notification.EventType_EVENT_OFFER_TENANCY_TERMINATE_CLAIM_DISPUTED_LAST_CHANCE_NOTIFY_TENANT:
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_EMAIL,
						template.WithSendgridTemplate("d-974330094e464ef1afac4c2034b5dd73"),
					),
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_PLATFORM,
						template.WithGoTemplate(
							`Last chance to settle your claims before they are taken to adjudication`,
						),
					),
				),
			),
		),
	),
}
