// Package viewing notification actions
package viewing

import (
	"time"

	notification "gitlab.mashroom.com/mashroom/backend/notification/api"
	"gitlab.mashroom.com/mashroom/backend/notification/internal/template"
)

// Registry map
var Registry = template.ActionMap{
	notification.Action_ACTION_ACCEPT: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_UNKNOWN,
			notification.Role_ROLE_TENANT,
			// notification.EventType_EVENT_VIEWING_ACCEPT_TENANT:
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_EMAIL,
				template.WithSendgridTemplate("d-04a87e5742c3416a917f2d846b8562f6"),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_SMS,
				template.WithGoTemplate(
					`Good news! Your viewing request has been accepted!`,
				),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_PLATFORM,
				template.WithTitle(
					`Viewing Accepted`,
				),
				template.WithGoTemplate(
					`Your viewing request has been accepted! `,
				),
			),
		),
	),
	notification.Action_ACTION_CANCEL: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_UNKNOWN,
			notification.Role_ROLE_MANAGER,
			// notification.EventType_EVENT_VIEWING_REQUEST_MANAGER_CANCEL:
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_EMAIL,
				template.WithSendgridTemplate("d-ec52daf6716c4479b0074e88fd91ef67"),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_SMS,
				template.WithGoTemplate(
					`A viewing scheduled for {{.property.name}} was cancelled. To arrange a new viewing, `+
						`please login to your dashboard here {{.site}}/dashboard/{{.property.id}}/overview`,
				),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_PLATFORM,
				template.WithGoTemplate(
					`A viewing scheduled for {{.property.name}} was canceled. To arrange a new viewing, `+
						`please visit your dashboard.`,
				),
			),
		),
	),
	notification.Action_ACTION_COMPLETE: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_MANAGER,
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-c293a036a69847189d874d90d4bdbd55"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`How was your viewing experience for {{.property.name}}? Log into your `+
							`dashboard to make an offer`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Viewing Completed`,
					),
					template.WithGoTemplate(
						`How was your viewing experience for {{.property.name}}?`+
							` You can make an offer through your dashboard now`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_VIEWING_COMPLETE_MANAGER:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-c293a036a69847189d874d90d4bdbd55"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`How was your viewing experience for {{.property.name}}? Log into your `+
							`dashboard to make an offer`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Viewing Completed`,
					),
					template.WithGoTemplate(
						`How was your viewing experience for {{.property.name}}?`+
							` You can make an offer through your dashboard now`,
					),
				),
				template.WithDuration(
					time.Minute*20,
					// notification.EventType_EVENT_VIEWING_COMPLETE_MANAGER_20MINS:
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_EMAIL,
						template.WithSendgridTemplate("d-828de6d4524a4c02817b5021eefff688"),
					),
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_SMS,
						template.WithGoTemplate(
							`How was your viewing at {{.property.name}}!`+
								` With Mashroom you can submit an offer at the price you think is fair.`+
								` Click this link to make an offer: `+
								`{{.site}}/offer/{{.property.id}}/new/start_page`+
								` Did you know that it only takes 30 seconds to leave feedback on your viewing`+
								` and by doing so, you’ll be automatically entered into our prize draw for a `+
								`£25 Amazon voucher!`+
								` You can leave feedback on your Timeline here: `+
								`{{.site}}/dashboard/{{.property.id}}/overview`,
						),
					),
				),
			),
		),
	),
	notification.Action_ACTION_CREATE: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_MANAGER,
				// notification.EventType_EVENT_VIEWING_REQUEST_MANAGER:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-b93d0fe4875e404e92d3b2a1acc60bb1"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`Hi {{.recipient.name}}, you have a viewing request for {{.property.name}}.`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`New Viewing Request`,
					),
					template.WithGoTemplate(
						`You've got a viewing request for {{.property.name}}.`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_VIEWING_REQUEST_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-688b31c371ba4d5a8ff332767a62423a"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithTitle(
						`Viewing Request`,
					),
					template.WithGoTemplate(
						`Your viewing request for {{.property.name}} has been sent.`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_EXPIRE: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_MANAGER,
				// notification.EventType_EVENT_VIEWING_REQUEST_MANAGER_EXPIRED:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-ef87a7bbe4ab4fa3a16d4bf2bcd36b2e"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`A request to view {{.property.location.city}} has expired.`+
							` If you have any other pending requests, you can manage them in your dashboard.`,
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_VIEWING_REQUEST_TENANT_EXPIRED:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-d5dad39805064e5b8c3e4178f2c56bc3"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`A request to view {{.property.location.city}} has expired.`+
							` If you have any other pending requests, you can manage them in your dashboard.`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_PENDING: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_UNKNOWN,
			notification.Role_ROLE_MANAGER,
			template.WithDuration(
				time.Hour*12,
				// notification.EventType_EVENT_VIEWING_REQUEST_MANAGER_REMIND_12HOURS:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-a8fc1d6613354590865b036622b15c13"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`You recently received a viewing request for {{.property.name}}.`+
							` To respond, login to your dashboard here`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`You recently received a viewing request for {{.property.name}}.`,
					),
				),
			),
			template.WithDuration(
				time.Hour*3,
				// notification.EventType_EVENT_VIEWING_REQUEST_MANAGER_REMIND_3HOURS:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-a8fc1d6613354590865b036622b15c13"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_SMS,
					template.WithGoTemplate(
						`You recently received a viewing request for {{.property.name}}.`+
							` To respond, login to your dashboard here`,
					),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`You recently received a viewing request for {{.property.name}}.`,
					),
				),
			),
		),
	),
	notification.Action_ACTION_REJECT: template.Action(
		template.WithActorRole(
			notification.Role_ROLE_UNKNOWN,
			notification.Role_ROLE_TENANT,
			// notification.EventType_EVENT_VIEWING_DECLINE_TENANT:
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_EMAIL,
				template.WithSendgridTemplate("d-335db01ae0da4d71965ae790831f0064"),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_SMS,
				template.WithGoTemplate(
					`Sorry {{.recipient.name}}, but your viewing request for {{.property.name}} has `+
						`been declined!`+
						` Log into your account to reschedule.`,
				),
			),
			template.WithChannel(
				notification.EventChannel_EVENT_CHANNEL_PLATFORM,
				template.WithTitle(
					`Viewing Declined`,
				),
				template.WithGoTemplate(
					`Your viewing request has been declined. You can try and reschedule it for another time.`,
				),
			),
		),
	),
	notification.Action_ACTION_REMIND: template.Action(
		template.WithActor(
			notification.Role_ROLE_UNKNOWN,
			template.WithRole(
				notification.Role_ROLE_MANAGER,
				// notification.EventType_EVENT_VIEWING_TODAY_NOTIFY_LANDLORD:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-5e7dd21bfaff4462ab980441b204428b"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`Your viewing at {{.property.name}} is scheduled for today.`,
					),
				),
				template.WithDuration(
					time.Hour*12,
					// notification.EventType_EVENT_VIEWING_ACCEPTED_REMIND_LANDLORD_12HOUR:
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_EMAIL,
						template.WithSendgridTemplate("d-c0912b357b4845fca49a2e43aa961da7"),
					),
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_PLATFORM,
						template.WithGoTemplate(
							`You have a viewing coming up in 12 hours at {{.property.name}}!`,
						),
					),
				),
				template.WithDuration(
					time.Hour*24,
					// notification.EventType_EVENT_VIEWING_ACCEPTED_REMIND_LANDLORD_1DAY:
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_EMAIL,
						template.WithSendgridTemplate("d-c0912b357b4845fca49a2e43aa961da7"),
					),
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_PLATFORM,
						template.WithGoTemplate(
							`You have a viewing you are hosting at {{.property.name}} in 1 day!`,
						),
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_TENANT,
				// notification.EventType_EVENT_VIEWING_TODAY_NOTIFY_TENANT:
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_EMAIL,
					template.WithSendgridTemplate("d-4bbe74bf6bb6451fa45506fcd05883cf"),
				),
				template.WithChannel(
					notification.EventChannel_EVENT_CHANNEL_PLATFORM,
					template.WithGoTemplate(
						`Your viewing at {{.property.name}} is scheduled for today.`,
					),
				),
				template.WithDuration(
					time.Hour*12,
					// notification.EventType_EVENT_VIEWING_ACCEPTED_REMIND_TENANT_12HOUR:
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_EMAIL,
						template.WithSendgridTemplate("d-57a3519b90d74d8d98eb32e467365812"),
					),
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_PLATFORM,
						template.WithGoTemplate(
							`You have a viewing coming up in 12 hours at {{.property.name}}!`,
						),
					),
				),
				template.WithDuration(
					time.Hour*24,
					// notification.EventType_EVENT_VIEWING_ACCEPTED_REMIND_TENANT_1DAY:
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_EMAIL,
						template.WithSendgridTemplate("d-57a3519b90d74d8d98eb32e467365812"),
					),
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_PLATFORM,
						template.WithGoTemplate(
							`You have a viewing you are hosting at {{.property.name}} in 1 day!`,
						),
					),
				),
			),
			template.WithRole(
				notification.Role_ROLE_UNKNOWN,
				template.WithDuration(
					time.Hour*48,
					// notification.EventType_EVENT_VIEWING_ACCEPTED_REMIND_2DAY:
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_EMAIL,
						template.WithSendgridTemplate("d-ef6dccc2f6214e4b9cd9e94b8f0991f7"),
					),
					template.WithChannel(
						notification.EventChannel_EVENT_CHANNEL_PLATFORM,
						template.WithGoTemplate(
							`You have a viewing coming up in 2 days at {{.property.name}}!`,
						),
					),
				),
			),
		),
	),
}
